Datasets
=========

| To easily exchange images and perform inter-implementation tests, we have defined a set of rules.
| ANYBODY who wants somebody else to test a set of images has to follow this convention.

`emva.process.parser.ParseEmvaDescriptorFile` accepts the dataset des We recomment using this class to read and process datasets.

.. toctree::
   :maxdepth: 4 
   
   datasets_image
   datasets_results